@@ -5,7 +5,7 @@
  * Copyright (C) 2003 Alastair McKinstry, <mckinstry@debian.org>
  * Released under the GPL
  *
- * $Id: acorn-kbd.c 11900 2004-03-24 21:52:04Z mckinstry $
+ * $Id: acorn-kbd.c 27318 2005-05-05 16:46:40Z cjwatson $
  */
 
 #include "config.h"
@@ -38,7 +38,7 @@ kbd_t *acorn_kbd_get (kbd_t *keyboards, const char *subarch)
 		di_warning ("acorn-kbd: failed to open /proc/cpuinfo.");
 		return keyboards;
 	}
-	if (res != 0) { // Not an acorn
+	if (res == 0) { // Not an acorn
 		k->present = FALSE;
 		return keyboards;
 	}
